@@ -1,7 +1,7 @@
 /*
    Text conversion from one charset to another.
 
-   Copyright (C) 2001-2016
+   Copyright (C) 2001-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -36,6 +36,8 @@
 #include "lib/global.h"
 #include "lib/strutil.h"        /* utf-8 functions */
 #include "lib/fileloc.h"
+#include "lib/util.h"           /* whitespace() */
+
 #include "lib/charsets.h"
 
 /*** global variables ****************************************************************************/
@@ -111,7 +113,7 @@ load_codepages_list_from_file (GPtrArray ** list, const char *fname)
 
         if (buflen > 0 && buf[buflen - 1] == '\n')
             buf[buflen - 1] = '\0';
-        while (*p != '\t' && *p != ' ' && *p != '\0')
+        while (*p != '\0' && !whitespace (*p))
             ++p;
         if (*p == '\0')
             goto fail;
@@ -225,6 +227,8 @@ free_codepages_list (void)
 {
     g_ptr_array_foreach (codepages, free_codepage_desc, NULL);
     g_ptr_array_free (codepages, TRUE);
+    /* NULL-ize pointer to make unit tests happy */
+    codepages = NULL;
 }
 
 /* --------------------------------------------------------------------------------------------- */
