@@ -1,6 +1,6 @@
 /* A more useful interface to strtol.
 
-   Copyright (C) 1995-2016
+   Copyright (C) 1995-2017
    Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -24,9 +24,6 @@
    need stderr defined if assertion checking is enabled.  */
 #include <stdio.h>
 
-#ifdef HAVE_ASSERT_H
-#include <assert.h>
-#endif
 #include <ctype.h>
 #include <errno.h>
 #include <inttypes.h>
@@ -84,9 +81,7 @@ xstrtoumax (const char *s, char **ptr, int base, uintmax_t * val, const char *va
     uintmax_t tmp;
     strtol_error_t err = LONGINT_OK;
 
-#ifdef HAVE_ASSERT_H
-    assert (0 <= base && base <= 36);
-#endif
+    g_assert (0 <= base && base <= 36);
 
     p = (ptr != NULL ? ptr : &t_ptr);
 
@@ -142,30 +137,47 @@ xstrtoumax (const char *s, char **ptr, int base, uintmax_t * val, const char *va
 
         base = 1024;
 
-        if (strchr (valid_suffixes, '0') != NULL)
+        switch (**p)
         {
-            /* The "valid suffix" '0' is a special flag meaning that
-               an optional second suffix is allowed, which can change
-               the base.  A suffix "B" (e.g. "100MB") stands for a power
-               of 1000, whereas a suffix "iB" (e.g. "100MiB") stands for
-               a power of 1024.  If no suffix (e.g. "100M"), assume
-               power-of-1024.  */
-
-            switch (p[0][1])
+        case 'E':
+        case 'G':
+        case 'g':
+        case 'k':
+        case 'K':
+        case 'M':
+        case 'm':
+        case 'P':
+        case 'T':
+        case 't':
+        case 'Y':
+        case 'Z':
+            if (strchr (valid_suffixes, '0') != NULL)
             {
-            case 'i':
-                if (p[0][2] == 'B')
-                    suffixes += 2;
-                break;
+                /* The "valid suffix" '0' is a special flag meaning that
+                   an optional second suffix is allowed, which can change
+                   the base.  A suffix "B" (e.g. "100MB") stands for a power
+                   of 1000, whereas a suffix "iB" (e.g. "100MiB") stands for
+                   a power of 1024.  If no suffix (e.g. "100M"), assume
+                   power-of-1024.  */
 
-            case 'B':
-            case 'D':          /* 'D' is obsolescent */
-                base = 1000;
-                suffixes++;
-                break;
-            default:
-                break;
+                switch (p[0][1])
+                {
+                case 'i':
+                    if (p[0][2] == 'B')
+                        suffixes += 2;
+                    break;
+
+                case 'B':
+                case 'D':      /* 'D' is obsolescent */
+                    base = 1000;
+                    suffixes++;
+                    break;
+                default:
+                    break;
+                }
             }
+        default:
+            break;
         }
 
         switch (**p)
@@ -175,6 +187,9 @@ xstrtoumax (const char *s, char **ptr, int base, uintmax_t * val, const char *va
             break;
 
         case 'B':
+            /* This obsolescent first suffix is distinct from the 'B'
+               second suffix above.  E.g., 'tar -L 1000B' means change
+               the tape after writing 1000 KiB of data.  */
             overflow = bkm_scale (&tmp, 1024);
             break;
 
