@@ -1,7 +1,7 @@
 /*
    Internal stuff of color setup
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -93,11 +93,25 @@ static mc_tty_color_table_t const attributes_table[] = {
     {NULL, 0}
 };
 
+/* --------------------------------------------------------------------------------------------- */
 /*** file scope functions ************************************************************************/
 /* --------------------------------------------------------------------------------------------- */
 
+static inline int
+parse_hex_digit (char c)
+{
+    if (c >= '0' && c <= '9')
+        return c - '0';
+    c |= 0x20;
+    if (c >= 'a' && c <= 'f')
+        return c - 'a' + 10;
+    return -1;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static int
-parse_256_color_name (const char *color_name)
+parse_256_or_true_color_name (const char *color_name)
 {
     int i;
     char dummy;
@@ -119,6 +133,30 @@ parse_256_color_name (const char *color_name)
     {
         return 16 + 36 * (color_name[3] - '0') + 6 * (color_name[4] - '0') + (color_name[5] - '0');
     }
+    if (color_name[0] == '#')
+    {
+        int len;
+        int h[6];
+
+        color_name++;
+        len = (int) strlen (color_name);
+        if (len != 3 && len != 6)
+            return -1;
+
+        for (i = 0; i < len; i++)
+        {
+            h[i] = parse_hex_digit (color_name[i]);
+            if (h[i] == -1)
+                return -1;
+        }
+
+        if (i == 3)
+            i = (h[0] << 20) | (h[0] << 16) | (h[1] << 12) | (h[1] << 8) | (h[2] << 4) | h[2];
+        else
+            i = (h[0] << 20) | (h[1] << 16) | (h[2] << 12) | (h[3] << 8) | (h[4] << 4) | h[5];
+        return (1 << 24) | i;
+    }
+
     return -1;
 }
 
@@ -136,21 +174,17 @@ tty_color_get_name_by_index (int idx)
     for (i = 0; color_table[i].name != NULL; i++)
         if (idx == color_table[i].value)
             return color_table[i].name;
-    /* Create and return the strings "color16" to "color255". */
-    if (idx >= 16 && idx < 256)
-    {
-        static char **color_N_names = NULL;
 
-        if (color_N_names == NULL)
-        {
-            color_N_names = g_try_malloc0 (240 * sizeof (char *));
-        }
-        if (color_N_names[idx - 16] == NULL)
-        {
-            color_N_names[idx - 16] = g_try_malloc (9);
-            sprintf (color_N_names[idx - 16], "color%d", idx);
-        }
-        return color_N_names[idx - 16];
+    /* Create and return the strings in "colorNNN" or "#rrggbb" format. */
+    if ((idx >= 16 && idx < 256) || (idx & (1 << 24)) != 0)
+    {
+        char name[9];
+
+        if (idx < 256)
+            sprintf (name, "color%d", idx);
+        else
+            sprintf (name, "#%06X", (unsigned int) idx & 0xFFFFFF);
+        return g_intern_string (name);
     }
     return "default";
 }
@@ -167,7 +201,7 @@ tty_color_get_index_by_name (const char *color_name)
         for (i = 0; color_table[i].name != NULL; i++)
             if (strcmp (color_name, color_table[i].name) == 0)
                 return color_table[i].value;
-        return parse_256_color_name (color_name);
+        return parse_256_or_true_color_name (color_name);
     }
     return -1;
 }
