@@ -1,8 +1,8 @@
 /*
    X11 support for the Midnight Commander.
 
-   Copyright (C) 2005, 2007, 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2005-2017
+   Free Software Foundation, Inc.
 
    Written by:
    Roland Illig <roland.illig@gmx.de>, 2005.
