@@ -1,7 +1,7 @@
 /*
    Various utilities - Unix variants
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -357,6 +357,7 @@ save_stop_handler (void)
  */
 
 void
+/* __attribute__ ((noreturn)) */
 my_exit (int status)
 {
     _exit (status);
@@ -453,7 +454,7 @@ my_systemv (const char *command, char *const argv[])
             execvp (command, argv);
             my_exit (127);      /* Exec error */
         }
-        break;
+        /* no break here, or unreachable-code warning by no returning my_exit() */
     default:
         status = 0;
         break;
