@@ -16,8 +16,8 @@ extern WDialog *midnight_dlg;
 
 /*** declarations of public functions ************************************************************/
 
-void dialog_switch_add (struct WDialog *h);
-void dialog_switch_remove (struct WDialog *h);
+void dialog_switch_add (WDialog * h);
+void dialog_switch_remove (WDialog * h);
 size_t dialog_switch_num (void);
 
 void dialog_switch_next (void);
