@@ -1,7 +1,7 @@
 /*
    Widgets for the Midnight Commander
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    Authors:
@@ -107,7 +107,7 @@ history_dlg_reposition (WDialog * dlg_head)
         x = COLS - wi;
     }
 
-    dlg_set_position (dlg_head, y, x, y + he, x + wi);
+    dlg_set_position (dlg_head, y, x, he, wi);
 
     return MSG_HANDLED;
 }
@@ -319,8 +319,8 @@ history_show (GList ** history, Widget * widget, int current)
     hist_data.maxlen = maxlen;
 
     query_dlg =
-        dlg_create (TRUE, 0, 0, 4, 4, dialog_colors, history_dlg_callback, NULL,
-                    "[History-query]", _("History"), DLG_COMPACT);
+        dlg_create (TRUE, 0, 0, 4, 4, WPOS_KEEP_DEFAULT, TRUE, dialog_colors, history_dlg_callback,
+                    NULL, "[History-query]", _("History"));
     query_dlg->data = &hist_data;
 
     query_list = listbox_new (1, 1, 2, 2, TRUE, NULL);
