@@ -48,8 +48,7 @@ typedef struct
     Widget widget;
     const int *color;
     int point;                  /* cursor position in the input line in characters */
-    int mark;                   /* the mark position in characters */
-    gboolean highlight;         /* there is a selected block */
+    int mark;                   /* the mark position in characters; negative value means no marked text */
     int term_first_shown;       /* column of the first shown character */
     size_t current_max_size;    /* maximum length of input line (bytes) */
     gboolean first;             /* is first keystroke? */
@@ -93,6 +92,7 @@ void input_set_default_colors (void);
 cb_ret_t input_handle_char (WInput * in, int key);
 int input_key_is_in_map (WInput * in, int key);
 void input_assign_text (WInput * in, const char *text);
+gboolean input_is_empty (const WInput * in);
 void input_insert (WInput * in, const char *text, gboolean insert_extra_space);
 void input_set_point (WInput * in, int pos);
 void input_update (WInput * in, gboolean clear_first);
