@@ -31,7 +31,6 @@ typedef struct WMenuBar
     Widget widget;
 
     gboolean is_visible;        /* If the menubar is visible */
-    gboolean is_active;         /* If the menubar is in use */
     gboolean is_dropped;        /* If the menubar has dropped */
     GList *menu;                /* The actual menus */
     guint selected;             /* Selected menu on the top bar */
@@ -56,6 +55,8 @@ void menubar_arrange (WMenuBar * menubar);
 
 WMenuBar *find_menubar (const WDialog * h);
 
+void menubar_activate (WMenuBar * menubar, gboolean dropped, int which);
+
 /*** inline functions ****************************************************************************/
 
 static inline void
