@@ -31,34 +31,34 @@ typedef struct WEdit WEdit;
 /*** global variables defined in .c file *********************************************************/
 
 extern int option_word_wrap_line_length;
-extern int option_typewriter_wrap;
-extern int option_auto_para_formatting;
-extern int option_fill_tabs_with_spaces;
-extern int option_return_does_auto_indent;
-extern int option_backspace_through_tabs;
-extern int option_fake_half_tabs;
-extern int option_persistent_selections;
-extern int option_drop_selection_on_copy;
-extern int option_cursor_beyond_eol;
+extern gboolean option_typewriter_wrap;
+extern gboolean option_auto_para_formatting;
+extern gboolean option_fill_tabs_with_spaces;
+extern gboolean option_return_does_auto_indent;
+extern gboolean option_backspace_through_tabs;
+extern gboolean option_fake_half_tabs;
+extern gboolean option_persistent_selections;
+extern gboolean option_drop_selection_on_copy;
+extern gboolean option_cursor_beyond_eol;
 extern gboolean option_cursor_after_inserted_block;
-extern int option_state_full_filename;
-extern int option_line_state;
+extern gboolean option_state_full_filename;
+extern gboolean option_line_state;
 extern int option_save_mode;
-extern int option_save_position;
-extern int option_syntax_highlighting;
-extern int option_group_undo;
+extern gboolean option_save_position;
+extern gboolean option_syntax_highlighting;
+extern gboolean option_group_undo;
 extern char *option_backup_ext;
 extern char *option_filesize_threshold;
 extern char *option_stop_format_chars;
 
-extern int edit_confirm_save;
+extern gboolean edit_confirm_save;
 
-extern int visible_tabs;
-extern int visible_tws;
+extern gboolean visible_tabs;
+extern gboolean visible_tws;
 
-extern int simple_statusbar;
-extern int option_check_nl_at_eof;
-extern int show_right_margin;
+extern gboolean simple_statusbar;
+extern gboolean option_check_nl_at_eof;
+extern gboolean show_right_margin;
 
 /*** declarations of public functions ************************************************************/
 
