@@ -1,7 +1,7 @@
 /*
    Editor menu definitions and initialisation
 
-   Copyright (C) 1996-2016
+   Copyright (C) 1996-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -268,17 +268,7 @@ edit_drop_menu_cmd (WDialog * h, int which)
     WMenuBar *menubar;
 
     menubar = find_menubar (h);
-
-    if (!menubar->is_active)
-    {
-        menubar->is_active = TRUE;
-        menubar->is_dropped = (drop_menus != 0);
-        if (which >= 0)
-            menubar->selected = (guint) which;
-
-        menubar->previous_widget = dlg_get_current_widget_id (h);
-        dlg_select_widget (menubar);
-    }
+    menubar_activate (menubar, drop_menus, which);
 }
 
 /* --------------------------------------------------------------------------------------------- */
