@@ -1,7 +1,7 @@
 /*
    Chown-advanced command -- for the Midnight Commander
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    This file is part of the Midnight Commander.
@@ -64,11 +64,6 @@
 
 #define B_SETALL        B_USER
 #define B_SKIP          (B_USER + 1)
-#define B_OWN           (B_USER + 3)
-#define B_GRP           (B_USER + 4)
-#define B_OTH           (B_USER + 5)
-#define B_OUSER         (B_USER + 6)
-#define B_OGROUP        (B_USER + 7)
 
 /*** file scope type declarations ****************************************************************/
 
@@ -284,7 +279,7 @@ update_mode (WDialog * h)
 {
     print_flags ();
     chown_info_update ();
-    send_message (h->current->data, NULL, MSG_FOCUS, 0, NULL);
+    widget_set_state (WIDGET (h->current->data), WST_FOCUSED, TRUE);
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -340,8 +335,8 @@ do_enter_key (WDialog * h, int f_pos)
         chl_end = FALSE;
 
         chl_dlg =
-            dlg_create (TRUE, lyy, lxx, 13, 17, dialog_colors, chl_callback, NULL,
-                        "[Advanced Chown]", title, DLG_COMPACT);
+            dlg_create (TRUE, lyy, lxx, 13, 17, WPOS_KEEP_DEFAULT, TRUE, dialog_colors,
+                        chl_callback, NULL, "[Advanced Chown]", title);
 
         /* get new listboxes */
         chl_list = listbox_new (1, 1, 11, 15, FALSE, NULL);
@@ -405,7 +400,7 @@ do_enter_key (WDialog * h, int f_pos)
                     ch_flags[f_pos + 6] = '+';
                     update_ownership ();
                 }
-                dlg_focus (h);
+                dlg_select_current_widget (h);
                 if (ok)
                     print_flags ();
             }
@@ -413,14 +408,14 @@ do_enter_key (WDialog * h, int f_pos)
             {
                 if (!is_owner)
                     chl_end = TRUE;
-                dlg_one_up (ch_dlg);
+                dlg_select_prev_widget (ch_dlg);
                 f_pos--;
             }
             else if (result == KEY_RIGHT)
             {
                 if (is_owner)
                     chl_end = TRUE;
-                dlg_one_down (ch_dlg);
+                dlg_select_next_widget (ch_dlg);
                 f_pos++;
             }
         }
@@ -551,7 +546,7 @@ advanced_chown_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm
             x_toggle ^= (1 << parm);
             update_mode (h);
             dlg_broadcast_msg (h, MSG_DRAW);
-            send_message (h->current->data, NULL, MSG_FOCUS, 0, NULL);
+            widget_set_state (WIDGET (h->current->data), WST_FOCUSED, TRUE);
             break;
 
         case XCTRL ('x'):
@@ -567,7 +562,7 @@ advanced_chown_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm
             x_toggle ^= (1 << parm);
             update_mode (h);
             dlg_broadcast_msg (h, MSG_DRAW);
-            send_message (h->current->data, NULL, MSG_FOCUS, 0, NULL);
+            widget_set_state (WIDGET (h->current->data), WST_FOCUSED, TRUE);
             break;
 
         case 'x':
@@ -618,7 +613,7 @@ advanced_chown_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm
                 update_mode (h);
                 send_message (h, sender, MSG_KEY, KEY_RIGHT, NULL);
                 if (flag_pos > 8 || (flag_pos % 3) == 0)
-                    dlg_one_down (h);
+                    dlg_select_next_widget (h);
             }
             break;
 
@@ -674,8 +669,8 @@ init_chown_advanced (void)
         dlg_h += 2;
 
     ch_dlg =
-        dlg_create (TRUE, 0, 0, dlg_h, dlg_w, dialog_colors, advanced_chown_callback, NULL,
-                    "[Advanced Chown]", _("Chown advanced command"), DLG_CENTER);
+        dlg_create (TRUE, 0, 0, dlg_h, dlg_w, WPOS_CENTER, FALSE, dialog_colors,
+                    advanced_chown_callback, NULL, "[Advanced Chown]", _("Chown advanced command"));
 
 
     l_filename = label_new (2, 3, "");
@@ -738,7 +733,7 @@ init_chown_advanced (void)
                                                        chown_advanced_but[i].flags,
                                                        chown_advanced_but[i].text, NULL));
 
-    dlg_select_widget (b_att[0]);
+    widget_select (WIDGET (b_att[0]));
 }
 
 /* --------------------------------------------------------------------------------------------- */
