@@ -1,7 +1,7 @@
 /*
    Some misc dialog boxes for the program.
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -130,9 +130,9 @@ configure_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, voi
     {
     case MSG_NOTIFY:
         /* message from "Single press" checkbutton */
-        if (sender != NULL && sender->id == configure_old_esc_mode_id && parm == (int) MSG_FOCUS)
+        if (sender != NULL && sender->id == configure_old_esc_mode_id)
         {
-            const gboolean not_single = !(CHECK (sender)->state & C_BOOL);
+            const gboolean not_single = !CHECK (sender)->state;
             Widget *ww;
 
             /* input line */
@@ -182,6 +182,31 @@ skin_name_to_label (const gchar * name)
 
 /* --------------------------------------------------------------------------------------------- */
 
+static cb_ret_t
+skin_dlg_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, void *data)
+{
+    switch (msg)
+    {
+    case MSG_RESIZE:
+        {
+            WDialog *d = DIALOG (w);
+            Widget *wd = WIDGET (d->data);
+            int y, x;
+
+            y = wd->y + (wd->lines - w->lines) / 2;
+            x = wd->x + wd->cols / 2;
+            dlg_set_position (d, y, x, w->lines, w->cols);
+
+            return MSG_HANDLED;
+        }
+
+    default:
+        return dlg_default_callback (w, sender, msg, parm, data);
+    }
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static int
 sel_skin_button (WButton * button, int action)
 {
@@ -189,17 +214,19 @@ sel_skin_button (WButton * button, int action)
     WListbox *skin_list;
     WDialog *skin_dlg;
     const gchar *skin_name;
-    int lxx, lyy;
     unsigned int i;
     unsigned int pos = 1;
 
     (void) action;
 
-    lxx = COLS / 2;
-    lyy = (LINES - 13) / 2;
     skin_dlg =
-        dlg_create (TRUE, lyy, lxx, 13, 24, WPOS_KEEP_DEFAULT, TRUE, dialog_colors, NULL, NULL,
-                    "[Appearance]", _("Skins"));
+        dlg_create (TRUE, 0, 0, 13, 24, WPOS_KEEP_DEFAULT, TRUE, dialog_colors, skin_dlg_callback,
+                    NULL, "[Appearance]", _("Skins"));
+    /* use Appearance dialog for positioning */
+    skin_dlg->data = WIDGET (button)->owner;
+
+    /* set dialog location before all */
+    send_message (skin_dlg, NULL, MSG_RESIZE, 0, NULL);
 
     skin_list = listbox_new (1, 1, 11, 22, FALSE, NULL);
     skin_name = "default";
@@ -222,7 +249,8 @@ sel_skin_button (WButton * button, int action)
         }
     }
 
-    add_widget (skin_dlg, skin_list);
+    /* make list stick to all sides of dialog, effectively make it be resized with dialog */
+    add_widget_autopos (skin_dlg, skin_list, WPOS_KEEP_ALL, NULL);
 
     result = dlg_run (skin_dlg);
     if (result == B_ENTER)
@@ -251,7 +279,7 @@ panel_listing_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm,
     switch (msg)
     {
     case MSG_NOTIFY:
-        if (sender != NULL && sender->id == panel_listing_types_id && parm == (int) MSG_FOCUS)
+        if (sender != NULL && sender->id == panel_listing_types_id)
         {
             WCheck *ch;
             WInput *in1, *in2, *in3;
@@ -261,7 +289,7 @@ panel_listing_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm,
             ch = CHECK (dlg_find_by_id (h, mini_user_status_id));
             in3 = INPUT (dlg_find_by_id (h, mini_user_format_id));
 
-            if (!(ch->state & C_BOOL))
+            if (!ch->state)
                 input_assign_text (in3, status_format[RADIO (sender)->sel]);
             input_update (in1, FALSE);
             input_update (in2, FALSE);
@@ -271,13 +299,13 @@ panel_listing_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm,
             return MSG_HANDLED;
         }
 
-        if (sender != NULL && sender->id == mini_user_status_id && parm == (int) MSG_FOCUS)
+        if (sender != NULL && sender->id == mini_user_status_id)
         {
             WInput *in;
 
             in = INPUT (dlg_find_by_id (h, mini_user_format_id));
 
-            if (CHECK (sender)->state & C_BOOL)
+            if (CHECK (sender)->state)
             {
                 widget_disable (WIDGET (in), FALSE);
                 input_assign_text (in, status_format[3]);
@@ -373,9 +401,9 @@ confvfs_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, void
     {
     case MSG_NOTIFY:
         /* message from "Always use ftp proxy" checkbutton */
-        if (sender != NULL && sender->id == ftpfs_always_use_proxy_id && parm == (int) MSG_FOCUS)
+        if (sender != NULL && sender->id == ftpfs_always_use_proxy_id)
         {
-            const gboolean not_use = !(CHECK (sender)->state & C_BOOL);
+            const gboolean not_use = !CHECK (sender)->state;
             Widget *wi;
 
             /* input */
@@ -601,7 +629,7 @@ appearance_box (void)
 void
 panel_options_box (void)
 {
-    int simple_swap;
+    gboolean simple_swap;
 
     simple_swap = mc_config_get_bool (mc_global.main_config, CONFIG_PANELS_SECTION,
                                       "simple_swap", FALSE) ? 1 : 0;
@@ -665,8 +693,7 @@ panel_options_box (void)
             return;
     }
 
-    mc_config_set_bool (mc_global.main_config, CONFIG_PANELS_SECTION,
-                        "simple_swap", (gboolean) (simple_swap & C_BOOL));
+    mc_config_set_bool (mc_global.main_config, CONFIG_PANELS_SECTION, "simple_swap", simple_swap);
 
     if (!panels_options.fast_reload_msg_shown && panels_options.fast_reload)
     {
@@ -684,7 +711,7 @@ panel_options_box (void)
 
 /* return list type */
 int
-panel_listing_box (WPanel * panel, int num, char **userp, char **minip, int *use_msformat,
+panel_listing_box (WPanel * panel, int num, char **userp, char **minip, gboolean * use_msformat,
                    int *brief_cols)
 {
     int result = -1;
@@ -699,7 +726,7 @@ panel_listing_box (WPanel * panel, int num, char **userp, char **minip, int *use
         panel = g_new (WPanel, 1);
         panel->list_type = list_full;
         panel->user_format = g_strdup (DEFAULT_USER_FORMAT);
-        panel->user_mini_status = 0;
+        panel->user_mini_status = FALSE;
         for (i = 0; i < LIST_TYPES; i++)
             panel->user_status_format[i] = g_strdup (DEFAULT_USER_FORMAT);
         section = g_strconcat ("Temporal:", p, (char *) NULL);
@@ -713,7 +740,7 @@ panel_listing_box (WPanel * panel, int num, char **userp, char **minip, int *use
     }
 
     {
-        int mini_user_status;
+        gboolean mini_user_status;
         char panel_brief_cols_in[BUF_TINY];
         char *panel_brief_cols_out = NULL;
         char *panel_user_format = NULL;
@@ -892,7 +919,7 @@ confirm_box (void)
 void
 display_bits_box (void)
 {
-    int new_meta;
+    gboolean new_meta;
     int current_mode;
 
     const char *display_bits_str[] = {
@@ -954,7 +981,7 @@ display_bits_box (void)
         : ((codepage_desc *) g_ptr_array_index (codepages, new_display_codepage))->name;
 
     {
-        int new_meta;
+        gboolean new_meta;
 
         quick_widget_t quick_widgets[] = {
             /* *INDENT-OFF* */
