@@ -1,7 +1,7 @@
 /*
    Find file command for the Midnight Commander
 
-   Copyright (C) 1995-2016
+   Copyright (C) 1995-2017
    Free Software Foundation, Inc.
 
    Written  by:
@@ -370,7 +370,8 @@ static void
 found_num_update (void)
 {
     char buffer[BUF_TINY];
-    g_snprintf (buffer, sizeof (buffer), _("Found: %ld"), matches);
+
+    g_snprintf (buffer, sizeof (buffer), _("Found: %lu"), matches);
     label_set_text (found_num_label, buffer);
 }
 
@@ -421,6 +422,14 @@ find_check_regexp (const char *r)
 
 /* --------------------------------------------------------------------------------------------- */
 
+static void
+find_toggle_enable_ignore_dirs (void)
+{
+    widget_disable (WIDGET (in_ignore), !ignore_dirs_cbox->state);
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static void
 find_toggle_enable_params (void)
 {
@@ -479,12 +488,9 @@ find_parm_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, voi
         return MSG_HANDLED;
 
     case MSG_NOTIFY:
-        if (sender == WIDGET (ignore_dirs_cbox) && parm == (int) MSG_FOCUS)
+        if (sender == WIDGET (ignore_dirs_cbox))
         {
-            gboolean disable = !(ignore_dirs_cbox->state & C_BOOL);
-
-            widget_disable (WIDGET (in_ignore), disable);
-
+            find_toggle_enable_ignore_dirs ();
             return MSG_HANDLED;
         }
 
@@ -495,8 +501,8 @@ find_parm_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, voi
             return MSG_HANDLED;
 
         /* check filename regexp */
-        if (!(file_pattern_cbox->state & C_BOOL)
-            && (in_name->buffer[0] != '\0') && !find_check_regexp (in_name->buffer))
+        if (!file_pattern_cbox->state && (in_name->buffer[0] != '\0')
+            && !find_check_regexp (in_name->buffer))
         {
             /* Don't stop the dialog */
             widget_set_state (WIDGET (h), WST_ACTIVE, TRUE);
@@ -506,7 +512,7 @@ find_parm_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, voi
         }
 
         /* check content regexp */
-        if ((content_regexp_cbox->state & C_BOOL) && (in_with->buffer[0] != '\0')
+        if (content_regexp_cbox->state && (in_with->buffer[0] != '\0')
             && !find_check_regexp (in_with->buffer))
         {
             /* Don't stop the dialog */
@@ -528,6 +534,7 @@ find_parm_callback (Widget * w, Widget * sender, widget_msg_t msg, int parm, voi
     case MSG_DRAW:
         if (first_draw)
         {
+            find_toggle_enable_ignore_dirs ();
             find_toggle_enable_params ();
             find_toggle_enable_content ();
         }
@@ -792,18 +799,18 @@ find_parameters (char **start_dir, ssize_t * start_dir_len,
             char *s;
 
 #ifdef HAVE_CHARSET
-            options.file_all_charsets = file_all_charsets_cbox->state & C_BOOL;
-            options.content_all_charsets = content_all_charsets_cbox->state & C_BOOL;
+            options.file_all_charsets = file_all_charsets_cbox->state;
+            options.content_all_charsets = content_all_charsets_cbox->state;
 #endif
-            options.content_case_sens = content_case_sens_cbox->state & C_BOOL;
-            options.content_regexp = content_regexp_cbox->state & C_BOOL;
-            options.content_first_hit = content_first_hit_cbox->state & C_BOOL;
-            options.content_whole_words = content_whole_words_cbox->state & C_BOOL;
-            options.find_recurs = recursively_cbox->state & C_BOOL;
-            options.file_pattern = file_pattern_cbox->state & C_BOOL;
-            options.file_case_sens = file_case_sens_cbox->state & C_BOOL;
-            options.skip_hidden = skip_hidden_cbox->state & C_BOOL;
-            options.ignore_dirs_enable = ignore_dirs_cbox->state & C_BOOL;
+            options.content_case_sens = content_case_sens_cbox->state;
+            options.content_regexp = content_regexp_cbox->state;
+            options.content_first_hit = content_first_hit_cbox->state;
+            options.content_whole_words = content_whole_words_cbox->state;
+            options.find_recurs = recursively_cbox->state;
+            options.file_pattern = file_pattern_cbox->state;
+            options.file_case_sens = file_case_sens_cbox->state;
+            options.skip_hidden = skip_hidden_cbox->state;
+            options.ignore_dirs_enable = ignore_dirs_cbox->state;
             g_free (options.ignore_dirs);
             options.ignore_dirs = g_strdup (in_ignore->buffer);
 
@@ -1301,9 +1308,10 @@ do_search (WDialog * h)
                         else
                         {
                             char msg[BUF_SMALL];
+
                             g_snprintf (msg, sizeof (msg),
-                                        ngettext ("Finished (ignored %zd directory)",
-                                                  "Finished (ignored %zd directories)",
+                                        ngettext ("Finished (ignored %zu directory)",
+                                                  "Finished (ignored %zu directories)",
                                                   ignore_count), ignore_count);
                             status_update (msg);
                         }
@@ -1438,10 +1446,10 @@ find_do_view_edit (gboolean unparsed_view, gboolean edit, char *dir, char *file,
 
     fullname_vpath = vfs_path_build_filename (dir, filename, (char *) NULL);
     if (edit)
-        edit_file_at_line (fullname_vpath, use_internal_edit != 0, line);
+        edit_file_at_line (fullname_vpath, use_internal_edit, line);
     else
-        view_file_at_line (fullname_vpath, unparsed_view, use_internal_view != 0, line,
-                           search_start, search_end);
+        view_file_at_line (fullname_vpath, unparsed_view, use_internal_view, line, search_start,
+                           search_end);
     vfs_path_free (fullname_vpath);
     g_free (fullname);
 }
