@@ -1,7 +1,7 @@
 /*
    External panelize
 
-   Copyright (C) 1995-2016
+   Copyright (C) 1995-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -63,7 +63,6 @@
 #define UX 3
 #define UY 2
 
-#define LABELS   3
 #define B_ADD    B_USER
 #define B_REMOVE (B_USER + 1)
 
@@ -168,8 +167,8 @@ init_panelize (void)
     panelize_cols = MAX (panelize_cols, blen + 4);
 
     panelize_dlg =
-        dlg_create (TRUE, 0, 0, 20, panelize_cols, dialog_colors, panelize_callback, NULL,
-                    "[External panelize]", _("External panelize"), DLG_CENTER);
+        dlg_create (TRUE, 0, 0, 20, panelize_cols, WPOS_CENTER, FALSE, dialog_colors,
+                    panelize_callback, NULL, "[External panelize]", _("External panelize"));
 
     /* add listbox to the dialogs */
     y = UY;
@@ -206,7 +205,7 @@ init_panelize (void)
         x += button_get_len (b) + 1;
     }
 
-    dlg_select_widget (l_panelize);
+    widget_select (WIDGET (l_panelize));
 }
 
 /* --------------------------------------------------------------------------------------------- */
