@@ -1,7 +1,7 @@
 /*
    User Menu implementation
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -115,15 +115,15 @@ check_patterns (char *p)
 
     p += sizeof (def_name) - 1;
     if (*p == '1')
-        easy_patterns = 1;
+        easy_patterns = TRUE;
     else if (*p == '0')
-        easy_patterns = 0;
+        easy_patterns = FALSE;
     else
         return p0;
 
     /* Skip spaces */
     p++;
-    while (*p == '\n' || *p == '\t' || *p == ' ')
+    while (whiteness (*p))
         p++;
     return p;
 }
@@ -135,7 +135,7 @@ check_patterns (char *p)
 static char *
 extract_arg (char *p, char *arg, int size)
 {
-    while (*p != '\0' && (*p == ' ' || *p == '\t' || *p == '\n'))
+    while (*p != '\0' && whiteness (*p))
         p++;
 
     /* support quote space .mnu */
@@ -456,9 +456,9 @@ execute_menu_command (const WEdit * edit_widget, const char *commands, gboolean
     {
         if (col == 0)
         {
-            if (*commands != ' ' && *commands != '\t')
+            if (!whitespace (*commands))
                 break;
-            while (*commands == ' ' || *commands == '\t')
+            while (whitespace (*commands))
                 commands++;
             if (*commands == '\0')
                 break;
@@ -922,7 +922,8 @@ user_menu_cmd (const WEdit * edit_widget, const char *menu_file, int selected_en
     int max_cols, menu_lines, menu_limit;
     int col, i;
     gboolean accept_entry = TRUE;
-    int selected, old_patterns;
+    int selected;
+    gboolean old_patterns;
     gboolean res = FALSE;
     gboolean interactive = TRUE;
 
@@ -1053,7 +1054,7 @@ user_menu_cmd (const WEdit * edit_widget, const char *menu_file, int selected_en
                         selected = menu_lines;
                 }
             }
-            else if (*p != ' ' && *p != '\t' && str_isprint (p))
+            else if (!whitespace (*p) && str_isprint (p))
             {
                 /* A menu entry title line */
                 if (accept_entry)
