@@ -2,7 +2,7 @@
    Virtual File System: FISH implementation for transfering files over
    shell connections.
 
-   Copyright (C) 1998-2016
+   Copyright (C) 1998-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -157,9 +157,35 @@ static char reply_str[80];
 
 static struct vfs_class vfs_fish_ops;
 
+/* --------------------------------------------------------------------------------------------- */
 /*** file scope functions ************************************************************************/
 /* --------------------------------------------------------------------------------------------- */
 
+static void
+fish_set_blksize (struct stat *s)
+{
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
+    /* redefine block size */
+    s->st_blksize = 64 * 1024;  /* FIXME */
+#endif
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static struct stat *
+fish_default_stat (struct vfs_class *me)
+{
+    struct stat *s;
+
+    s = vfs_s_default_stat (me, S_IFDIR | 0755);
+    fish_set_blksize (s);
+    vfs_adjust_stat (s);
+
+    return s;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static char *
 fish_load_script_from_file (const char *hostname, const char *script_name, const char *def_content)
 {
@@ -551,7 +577,8 @@ fish_open_archive_int (struct vfs_class *me, struct vfs_s_super *super)
     super->name = g_strdup (PATH_SEP_STR);
 #endif
 
-    super->root = vfs_s_new_inode (me, super, vfs_s_default_stat (me, S_IFDIR | 0755));
+    super->root = vfs_s_new_inode (me, super, fish_default_stat (me));
+
     return 0;
 }
 
@@ -1248,6 +1275,42 @@ fish_symlink (const vfs_path_t * vpath1, const vfs_path_t * vpath2)
 
 /* --------------------------------------------------------------------------------------------- */
 
+static int
+fish_stat (const vfs_path_t * vpath, struct stat *buf)
+{
+    int ret;
+
+    ret = vfs_s_stat (vpath, buf);
+    fish_set_blksize (buf);
+    return ret;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static int
+fish_lstat (const vfs_path_t * vpath, struct stat *buf)
+{
+    int ret;
+
+    ret = vfs_s_lstat (vpath, buf);
+    fish_set_blksize (buf);
+    return ret;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static int
+fish_fstat (void *vfs_info, struct stat *buf)
+{
+    int ret;
+
+    ret = vfs_s_fstat (vfs_info, buf);
+    fish_set_blksize (buf);
+    return ret;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static int
 fish_chmod (const vfs_path_t * vpath, mode_t mode)
 {
@@ -1323,17 +1386,49 @@ fish_chown (const vfs_path_t * vpath, uid_t owner, gid_t group)
 
 /* --------------------------------------------------------------------------------------------- */
 
+static void
+fish_get_atime (mc_timesbuf_t * times, time_t * sec, long *nsec)
+{
+#ifdef HAVE_UTIMENSAT
+    *sec = (*times)[0].tv_sec;
+    *nsec = (*times)[0].tv_nsec;
+#else
+    *sec = times->actime;
+    *nsec = 0;
+#endif
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static void
+fish_get_mtime (mc_timesbuf_t * times, time_t * sec, long *nsec)
+{
+#ifdef HAVE_UTIMENSAT
+    *sec = (*times)[1].tv_sec;
+    *nsec = (*times)[1].tv_nsec;
+#else
+    *sec = times->modtime;
+    *nsec = 0;
+#endif
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static int
-fish_utime (const vfs_path_t * vpath, struct utimbuf *times)
+fish_utime (const vfs_path_t * vpath, mc_timesbuf_t * times)
 {
     gchar *shell_commands = NULL;
-    char utcmtime[16], utcatime[16];
+    char utcatime[16], utcmtime[16];
+    char utcatime_w_nsec[30], utcmtime_w_nsec[30];
+    time_t atime, mtime;
+    long atime_nsec, mtime_nsec;
     struct tm *gmt;
-    char buf[BUF_LARGE];
+    char *cmd;
     const char *crpath;
     char *rpath;
     struct vfs_s_super *super;
     const vfs_path_element_t *path_element;
+    int ret;
 
     path_element = vfs_path_get_by_index (vpath, -1);
 
@@ -1342,24 +1437,38 @@ fish_utime (const vfs_path_t * vpath, struct utimbuf *times)
         return -1;
     rpath = strutils_shell_escape (crpath);
 
-    gmt = gmtime (&times->modtime);
-    g_snprintf (utcmtime, sizeof (utcmtime), "%04d%02d%02d%02d%02d.%02d",
-                gmt->tm_year + 1900, gmt->tm_mon + 1, gmt->tm_mday,
-                gmt->tm_hour, gmt->tm_min, gmt->tm_sec);
-
-    gmt = gmtime (&times->actime);
+    fish_get_atime (times, &atime, &atime_nsec);
+    gmt = gmtime (&atime);
     g_snprintf (utcatime, sizeof (utcatime), "%04d%02d%02d%02d%02d.%02d",
                 gmt->tm_year + 1900, gmt->tm_mon + 1, gmt->tm_mday,
                 gmt->tm_hour, gmt->tm_min, gmt->tm_sec);
+    g_snprintf (utcatime_w_nsec, sizeof (utcatime_w_nsec), "%04d-%02d-%02d %02d:%02d:%02d.%09ld",
+                gmt->tm_year + 1900, gmt->tm_mon + 1, gmt->tm_mday,
+                gmt->tm_hour, gmt->tm_min, gmt->tm_sec, atime_nsec);
+
+    fish_get_mtime (times, &mtime, &mtime_nsec);
+    gmt = gmtime (&mtime);
+    g_snprintf (utcmtime, sizeof (utcmtime), "%04d%02d%02d%02d%02d.%02d",
+                gmt->tm_year + 1900, gmt->tm_mon + 1, gmt->tm_mday,
+                gmt->tm_hour, gmt->tm_min, gmt->tm_sec);
+    g_snprintf (utcmtime_w_nsec, sizeof (utcmtime_w_nsec), "%04d-%02d-%02d %02d:%02d:%02d.%09ld",
+                gmt->tm_year + 1900, gmt->tm_mon + 1, gmt->tm_mday,
+                gmt->tm_hour, gmt->tm_min, gmt->tm_sec, mtime_nsec);
 
     shell_commands =
         g_strconcat (SUP->scr_env, "FISH_FILENAME=%s FISH_FILEATIME=%ld FISH_FILEMTIME=%ld ",
-                     "FISH_TOUCHATIME=%s FISH_TOUCHMTIME=%s;\n", SUP->scr_utime, (char *) NULL);
-    g_snprintf (buf, sizeof (buf), shell_commands, rpath, (long) times->actime,
-                (long) times->modtime, utcatime, utcmtime);
+                     "FISH_TOUCHATIME=%s FISH_TOUCHMTIME=%s ",
+                     "FISH_TOUCHATIME_W_NSEC=\"%s\" FISH_TOUCHMTIME_W_NSEC=\"%s\";\n",
+                     SUP->scr_utime, (char *) NULL);
+    cmd =
+        g_strdup_printf (shell_commands, rpath, (long) atime, (long) mtime, utcatime, utcmtime,
+                         utcatime_w_nsec, utcmtime_w_nsec);
     g_free (shell_commands);
     g_free (rpath);
-    return fish_send_command (path_element->class, super, buf, OPT_FLUSH);
+    ret = fish_send_command (path_element->class, super, cmd, OPT_FLUSH);
+    g_free (cmd);
+
+    return ret;
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -1622,6 +1731,9 @@ init_fish (void)
     vfs_fish_ops.name = "fish";
     vfs_fish_ops.prefix = "sh";
     vfs_fish_ops.fill_names = fish_fill_names;
+    vfs_fish_ops.stat = fish_stat;
+    vfs_fish_ops.lstat = fish_lstat;
+    vfs_fish_ops.fstat = fish_fstat;
     vfs_fish_ops.chmod = fish_chmod;
     vfs_fish_ops.chown = fish_chown;
     vfs_fish_ops.utime = fish_utime;
