@@ -1,7 +1,7 @@
 /*
    Virtual File System: FTP file system.
 
-   Copyright (C) 1995-2016
+   Copyright (C) 1995-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -118,21 +118,21 @@ What to do with this?
 int ftpfs_retry_seconds = 30;
 
 /* Method to use to connect to ftp sites */
-int ftpfs_use_passive_connections = 1;
-int ftpfs_use_passive_connections_over_proxy = 0;
+gboolean ftpfs_use_passive_connections = TRUE;
+gboolean ftpfs_use_passive_connections_over_proxy = FALSE;
 
 /* Method used to get directory listings:
  * 1: try 'LIST -la <path>', if it fails
  *    fall back to CWD <path>; LIST
  * 0: always use CWD <path>; LIST
  */
-int ftpfs_use_unix_list_options = 1;
+gboolean ftpfs_use_unix_list_options = TRUE;
 
 /* First "CWD <path>", then "LIST -la ." */
-int ftpfs_first_cd_then_ls = 1;
+gboolean ftpfs_first_cd_then_ls = TRUE;
 
 /* Use the ~/.netrc */
-int ftpfs_use_netrc = 1;
+gboolean ftpfs_use_netrc = TRUE;
 
 /* Anonymous setup */
 char *ftpfs_anonymous_passwd = NULL;
@@ -142,9 +142,9 @@ int ftpfs_directory_timeout = 900;
 char *ftpfs_proxy_host = NULL;
 
 /* whether we have to use proxy by default? */
-int ftpfs_always_use_proxy = 0;
+gboolean ftpfs_always_use_proxy = FALSE;
 
-int ftpfs_ignore_chattr_errors = 1;
+gboolean ftpfs_ignore_chattr_errors = TRUE;
 
 /*** file scope macro definitions ****************************************************************/
 
@@ -206,7 +206,7 @@ typedef struct
 
     char *proxy;                /* proxy server, NULL if no proxy */
     int failed_on_login;        /* used to pass the failure reason to upper levels */
-    int use_passive_connection;
+    gboolean use_passive_connection;
     int remote_is_amiga;        /* No leading slash allowed for AmiTCP (Amiga) */
     int isbinary;
     int cwd_deferred;           /* current_directory was changed but CWD command hasn't
@@ -244,6 +244,7 @@ static char buffer[BUF_MEDIUM];
 static char *netrc;
 static const char *netrcp;
 
+/* --------------------------------------------------------------------------------------------- */
 /*** file scope functions ************************************************************************/
 /* --------------------------------------------------------------------------------------------- */
 
@@ -270,6 +271,31 @@ static int ftpfs_netrc_lookup (const char *host, char **login, char **pass);
 
 /* --------------------------------------------------------------------------------------------- */
 
+static void
+ftpfs_set_blksize (struct stat *s)
+{
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
+    /* redefine block size */
+    s->st_blksize = 64 * 1024;  /* FIXME */
+#endif
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static struct stat *
+ftpfs_default_stat (struct vfs_class *me)
+{
+    struct stat *s;
+
+    s = vfs_s_default_stat (me, S_IFDIR | 0755);
+    ftpfs_set_blksize (s);
+    vfs_adjust_stat (s);
+
+    return s;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static char *
 ftpfs_translate_path (struct vfs_class *me, struct vfs_s_super *super, const char *remote_path)
 {
@@ -991,8 +1017,7 @@ ftpfs_open_archive (struct vfs_s_super *super,
     SUP->ctl_connection_busy = 0;
     super->name = g_strdup (PATH_SEP_STR);
     super->root =
-        vfs_s_new_inode (vpath_element->class, super,
-                         vfs_s_default_stat (vpath_element->class, S_IFDIR | 0755));
+        vfs_s_new_inode (vpath_element->class, super, ftpfs_default_stat (vpath_element->class));
 
     return ftpfs_open_archive_int (vpath_element->class, super);
 }
@@ -1320,7 +1345,7 @@ ftpfs_initconn (struct vfs_class *me, struct vfs_s_super *super)
             return data_sock;
 
         vfs_print_message ("%s", _("ftpfs: could not setup passive mode"));
-        SUP->use_passive_connection = 0;
+        SUP->use_passive_connection = FALSE;
 
         close (data_sock);
     }
@@ -1669,7 +1694,7 @@ ftpfs_dir_load (struct vfs_class *me, struct vfs_s_inode *dir, char *remote_path
     struct vfs_s_entry *ent;
     struct vfs_s_super *super = dir->super;
     int sock, num_entries = 0;
-    int cd_first;
+    gboolean cd_first;
 
     cd_first = ftpfs_first_cd_then_ls || (SUP->strict == RFC_STRICT)
         || (strchr (remote_path, ' ') != NULL);
@@ -1765,7 +1790,7 @@ ftpfs_dir_load (struct vfs_class *me, struct vfs_s_inode *dir, char *remote_path
     if ((ftpfs_get_reply (me, SUP->sock, NULL, 0) != COMPLETE))
         goto fallback;
 
-    if (num_entries == 0 && cd_first == 0)
+    if (num_entries == 0 && !cd_first)
     {
         /* The LIST command may produce an empty output. In such scenario
            it is not clear whether this is caused by  'remote_path' being
@@ -1777,7 +1802,7 @@ ftpfs_dir_load (struct vfs_class *me, struct vfs_s_inode *dir, char *remote_path
            to determine the type of 'remote_path'. The only reliable way to
            achieve this is trough issuing a CWD command. */
 
-        cd_first = 1;
+        cd_first = TRUE;
         goto again;
     }
 
@@ -1797,7 +1822,7 @@ ftpfs_dir_load (struct vfs_class *me, struct vfs_s_inode *dir, char *remote_path
         SUP->strict = RFC_STRICT;
         /* I hate goto, but recursive call needs another 8K on stack */
         /* return ftpfs_dir_load (me, dir, remote_path); */
-        cd_first = 1;
+        cd_first = TRUE;
         goto again;
     }
     vfs_print_message ("%s", _("ftpfs: failed; nowhere to fallback to"));
@@ -2020,13 +2045,49 @@ ftpfs_send_command (const vfs_path_t * vpath, const char *cmd, int flags)
 
 /* --------------------------------------------------------------------------------------------- */
 
+static int
+ftpfs_stat (const vfs_path_t * vpath, struct stat *buf)
+{
+    int ret;
+
+    ret = vfs_s_stat (vpath, buf);
+    ftpfs_set_blksize (buf);
+    return ret;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static int
+ftpfs_lstat (const vfs_path_t * vpath, struct stat *buf)
+{
+    int ret;
+
+    ret = vfs_s_lstat (vpath, buf);
+    ftpfs_set_blksize (buf);
+    return ret;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
+static int
+ftpfs_fstat (void *vfs_info, struct stat *buf)
+{
+    int ret;
+
+    ret = vfs_s_fstat (vfs_info, buf);
+    ftpfs_set_blksize (buf);
+    return ret;
+}
+
+/* --------------------------------------------------------------------------------------------- */
+
 static int
 ftpfs_chmod (const vfs_path_t * vpath, mode_t mode)
 {
     char buf[BUF_SMALL];
     int ret;
 
-    g_snprintf (buf, sizeof (buf), "SITE CHMOD %4.4o /%%s", (int) (mode & 07777));
+    g_snprintf (buf, sizeof (buf), "SITE CHMOD %4.4o /%%s", (unsigned int) (mode & 07777));
 
     ret = ftpfs_send_command (vpath, buf, OPT_FLUSH);
 
@@ -2306,8 +2367,7 @@ ftpfs_netrc_next (void)
     }
     else
     {
-        for (; *netrcp != '\n' && *netrcp != '\t' && *netrcp != ' ' &&
-             *netrcp != ',' && *netrcp; netrcp++)
+        for (; *netrcp != '\0' && !whiteness (*netrcp) && *netrcp != ','; netrcp++)
         {
             if (*netrcp == '\\')
                 netrcp++;
@@ -2608,6 +2668,9 @@ init_ftpfs (void)
     vfs_ftpfs_ops.prefix = "ftp";
     vfs_ftpfs_ops.done = &ftpfs_done;
     vfs_ftpfs_ops.fill_names = ftpfs_fill_names;
+    vfs_ftpfs_ops.stat = ftpfs_stat;
+    vfs_ftpfs_ops.lstat = ftpfs_lstat;
+    vfs_ftpfs_ops.fstat = ftpfs_fstat;
     vfs_ftpfs_ops.chmod = ftpfs_chmod;
     vfs_ftpfs_ops.chown = ftpfs_chown;
     vfs_ftpfs_ops.unlink = ftpfs_unlink;
