@@ -1,7 +1,7 @@
 /* Virtual File System: SFTP file system.
    The internal functions: dirs
 
-   Copyright (C) 2011-2015
+   Copyright (C) 2011-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -82,11 +82,15 @@ sftpfs_opendir (const vfs_path_t * vpath, GError ** mcerror)
 
     while (TRUE)
     {
+        const char *fixfname;
+        unsigned int fixfname_len = 0;
         int libssh_errno;
 
+        fixfname = sftpfs_fix_filename (path_element->path, &fixfname_len);
+
         handle =
-            libssh2_sftp_opendir (super_data->sftp_session,
-                                  sftpfs_fix_filename (path_element->path));
+            libssh2_sftp_open_ex (super_data->sftp_session, fixfname, fixfname_len, 0, 0,
+                                  LIBSSH2_SFTP_OPENDIR);
         if (handle != NULL)
             break;
 
@@ -209,12 +213,11 @@ sftpfs_mkdir (const vfs_path_t * vpath, mode_t mode, GError ** mcerror)
     do
     {
         const char *fixfname;
+        unsigned int fixfname_len = 0;
 
-        fixfname = sftpfs_fix_filename (path_element->path);
+        fixfname = sftpfs_fix_filename (path_element->path, &fixfname_len);
 
-        res =
-            libssh2_sftp_mkdir_ex (super_data->sftp_session,
-                                   fixfname, sftpfs_filename_buffer->len, mode);
+        res = libssh2_sftp_mkdir_ex (super_data->sftp_session, fixfname, fixfname_len, mode);
         if (res >= 0)
             break;
 
@@ -266,11 +269,11 @@ sftpfs_rmdir (const vfs_path_t * vpath, GError ** mcerror)
     do
     {
         const char *fixfname;
+        unsigned int fixfname_len = 0;
 
-        fixfname = sftpfs_fix_filename (path_element->path);
+        fixfname = sftpfs_fix_filename (path_element->path, &fixfname_len);
 
-        res =
-            libssh2_sftp_rmdir_ex (super_data->sftp_session, fixfname, sftpfs_filename_buffer->len);
+        res = libssh2_sftp_rmdir_ex (super_data->sftp_session, fixfname, fixfname_len);
         if (res >= 0)
             break;
 
