@@ -1,7 +1,7 @@
 /* Virtual File System: SFTP file system.
    The VFS class functions
 
-   Copyright (C) 2011-2016
+   Copyright (C) 2011-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -330,7 +330,7 @@ sftpfs_cb_readlink (const vfs_path_t * vpath, char *buf, size_t size)
  */
 
 static int
-sftpfs_cb_utime (const vfs_path_t * vpath, struct utimbuf *times)
+sftpfs_cb_utime (const vfs_path_t * vpath, mc_timesbuf_t * times)
 {
     (void) vpath;
     (void) times;
