@@ -7,8 +7,8 @@
 
    Copyright (C) Andrew Tridgell 1998
 
-   Copyright (C) 2011
-   The Free Software Foundation, Inc.
+   Copyright (C) 2011-2017
+   Free Software Foundation, Inc.
 
    This file is part of the Midnight Commander.
 
