@@ -1,7 +1,7 @@
 /*
    Virtual File System: GNU Tar file system.
 
-   Copyright (C) 1995-2016
+   Copyright (C) 1995-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -47,6 +47,7 @@
 
 #include "lib/global.h"
 #include "lib/util.h"
+#include "lib/unixcompat.h"     /* makedev() */
 #include "lib/widget.h"         /* message() */
 
 #include "lib/vfs/vfs.h"
@@ -401,7 +402,10 @@ tar_fill_stat (struct vfs_s_super *archive, struct stat *st, union record *heade
         st->st_mode |= S_IFREG;
 
     st->st_dev = 0;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
     st->st_rdev = 0;
+#endif
+
     switch (arch->type)
     {
     case TAR_USTAR:
@@ -420,16 +424,23 @@ tar_fill_stat (struct vfs_s_super *archive, struct stat *st, union record *heade
         {
         case LF_BLK:
         case LF_CHR:
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
             st->st_rdev =
-                (tar_from_oct (8, header->header.devmajor) << 8) |
-                tar_from_oct (8, header->header.devminor);
+                makedev (tar_from_oct (8, header->header.devmajor),
+                         tar_from_oct (8, header->header.devminor));
+#endif
+            break;
         default:
             break;
         }
+        break;
+
     default:
         st->st_uid = tar_from_oct (8, header->header.uid);
         st->st_gid = tar_from_oct (8, header->header.gid);
+        break;
     }
+
     st->st_size = h_size;
     st->st_mtime = tar_from_oct (1 + 12, header->header.mtime);
     st->st_atime = 0;
@@ -439,6 +450,11 @@ tar_fill_stat (struct vfs_s_super *archive, struct stat *st, union record *heade
         st->st_atime = tar_from_oct (1 + 12, header->header.unused.oldgnu.atime);
         st->st_ctime = tar_from_oct (1 + 12, header->header.unused.oldgnu.ctime);
     }
+
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
+    st->st_blksize = 8 * 1024;  /* FIXME */
+#endif
+    vfs_adjust_stat (st);
 }
 
 /* --------------------------------------------------------------------------------------------- */
