@@ -2,7 +2,7 @@
    Internal file viewer for the Midnight Commander
    Function for hex view
 
-   Copyright (C) 1994-2016
+   Copyright (C) 1994-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -389,9 +389,7 @@ mcview_hexedit_save_changes (WView * view)
         char *text;
         struct hexedit_change_node *curr, *next;
 
-#ifdef HAVE_ASSERT_H
-        assert (view->filename_vpath != NULL);
-#endif
+        g_assert (view->filename_vpath != NULL);
 
         fp = mc_open (view->filename_vpath, O_WRONLY);
         if (fp != -1)
