@@ -1,10 +1,6 @@
 #ifndef MC__VIEWER_INLINES_H
 #define MC__VIEWER_INLINES_H
 
-#ifdef HAVE_ASSERT_H
-#include <assert.h>
-#endif
-
 /*** typedefs(not structures) and defined constants **********************************************/
 
 /*** enums ***************************************************************************************/
@@ -29,9 +25,7 @@ mcview_offset_doz (off_t a, off_t b)
 static inline off_t
 mcview_offset_rounddown (off_t a, off_t b)
 {
-#ifdef HAVE_ASSERT_H
-    assert (b != 0);
-#endif
+    g_assert (b != 0);
     return a - a % b;
 }
 
@@ -77,9 +71,7 @@ mcview_already_loaded (off_t offset, off_t idx, size_t size)
 static inline gboolean
 mcview_get_byte_file (WView * view, off_t byte_index, int *retval)
 {
-#ifdef HAVE_ASSERT_H
-    assert (view->datasource == DS_FILE);
-#endif
+    g_assert (view->datasource == DS_FILE);
 
     mcview_file_load_data (view, byte_index);
     if (mcview_already_loaded (view->ds_file_offset, byte_index, view->ds_file_datalen))
@@ -110,9 +102,7 @@ mcview_get_byte (WView * view, off_t offset, int *retval)
     case DS_NONE:
         return mcview_get_byte_none (view, offset, retval);
     default:
-#ifdef HAVE_ASSERT_H
-        assert (!"Unknown datasource type");
-#endif
+        g_assert (!"Unknown datasource type");
         return FALSE;
     }
 }
