@@ -1,7 +1,7 @@
 /*
    lib - common code for testing lib/utilinux:my_system() function
 
-   Copyright (C) 2013-2016
+   Copyright (C) 2013-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -105,12 +105,15 @@ sigaction__deinit (void)
 {
     g_ptr_array_foreach (sigaction_signum__captured, (GFunc) g_free, NULL);
     g_ptr_array_free (sigaction_signum__captured, TRUE);
+    sigaction_signum__captured = NULL;
 
     g_ptr_array_foreach (sigaction_act__captured, (GFunc) g_free, NULL);
     g_ptr_array_free (sigaction_act__captured, TRUE);
+    sigaction_act__captured = NULL;
 
     g_ptr_array_foreach (sigaction_oldact__captured, (GFunc) g_free, NULL);
     g_ptr_array_free (sigaction_oldact__captured, TRUE);
+    sigaction_oldact__captured = NULL;
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -159,9 +162,11 @@ signal__deinit (void)
 {
     g_ptr_array_foreach (signal_signum__captured, (GFunc) g_free, NULL);
     g_ptr_array_free (signal_signum__captured, TRUE);
+    signal_signum__captured = NULL;
 
     g_ptr_array_foreach (signal_handler__captured, (GFunc) g_free, NULL);
     g_ptr_array_free (signal_handler__captured, TRUE);
+    signal_handler__captured = NULL;
 }
 
 /* --------------------------------------------------------------------------------------------- */
@@ -220,7 +225,8 @@ execvp__deinit (void)
 {
     g_ptr_array_foreach (execvp__args__captured, (GFunc) g_free, NULL);
     g_ptr_array_free (execvp__args__captured, TRUE);
-    g_free (execvp__file__captured);
+    execvp__args__captured = NULL;
+    MC_PTR_FREE (execvp__file__captured);
 }
 
 /* --------------------------------------------------------------------------------------------- */
