@@ -1,7 +1,7 @@
 /*
    lib/vfs - test vfs_parse_ls_lga() functionality
 
-   Copyright (C) 2011-2015
+   Copyright (C) 2011-2017
    Free Software Foundation, Inc.
 
    Written by:
@@ -119,10 +119,16 @@ fill_stat_struct (struct stat *etalon_stat, int iterator)
         etalon_stat->st_nlink = 10;
         etalon_stat->st_uid = 500;
         etalon_stat->st_gid = 500;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
         etalon_stat->st_rdev = 0;
+#endif
         etalon_stat->st_size = 4096;
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
         etalon_stat->st_blksize = 512;
+#endif
+#ifdef HAVE_STRUCT_STAT_ST_BLOCKS
         etalon_stat->st_blocks = 8;
+#endif
         etalon_stat->st_atime = 1308838140;
         etalon_stat->st_mtime = 1308838140;
         etalon_stat->st_ctime = 1308838140;
@@ -134,10 +140,16 @@ fill_stat_struct (struct stat *etalon_stat, int iterator)
         etalon_stat->st_nlink = 10;
         etalon_stat->st_uid = 500;
         etalon_stat->st_gid = 500;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
         etalon_stat->st_rdev = 0;
+#endif
         etalon_stat->st_size = 11;
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
         etalon_stat->st_blksize = 512;
+#endif
+#ifdef HAVE_STRUCT_STAT_ST_BLOCKS
         etalon_stat->st_blocks = 1;
+#endif
         etalon_stat->st_atime = 1268431200;
         etalon_stat->st_mtime = 1268431200;
         etalon_stat->st_ctime = 1268431200;
@@ -149,10 +161,16 @@ fill_stat_struct (struct stat *etalon_stat, int iterator)
         etalon_stat->st_nlink = 10;
         etalon_stat->st_uid = 500;
         etalon_stat->st_gid = 500;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
         etalon_stat->st_rdev = 0;
+#endif
         etalon_stat->st_size = 4096;
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
         etalon_stat->st_blksize = 512;
+#endif
+#ifdef HAVE_STRUCT_STAT_ST_BLOCKS
         etalon_stat->st_blocks = 8;
+#endif
         etalon_stat->st_atime = 1308838140;
         etalon_stat->st_mtime = 1308838140;
         etalon_stat->st_ctime = 1308838140;
@@ -164,10 +182,16 @@ fill_stat_struct (struct stat *etalon_stat, int iterator)
         etalon_stat->st_nlink = 10;
         etalon_stat->st_uid = 500;
         etalon_stat->st_gid = 500;
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
         etalon_stat->st_rdev = 0;
+#endif
         etalon_stat->st_size = 4096;
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
         etalon_stat->st_blksize = 512;
+#endif
+#ifdef HAVE_STRUCT_STAT_ST_BLOCKS
         etalon_stat->st_blocks = 8;
+#endif
         etalon_stat->st_atime = 1308838140;
         etalon_stat->st_mtime = 1308838140;
         etalon_stat->st_ctime = 1308838140;
@@ -237,7 +261,9 @@ START_PARAMETRIZED_TEST (test_vfs_parse_ls_lga, test_vfs_parse_ls_lga_ds)
 
     vfs_parse_ls_lga_init ();
 
+#ifdef HAVE_STRUCT_STAT_ST_BLOCKS
     etalon_stat.st_blocks = 0;
+#endif
     etalon_stat.st_size = 0;
     etalon_stat.st_mode = 0;
     fill_stat_struct (&etalon_stat, _i);
@@ -257,10 +283,16 @@ START_PARAMETRIZED_TEST (test_vfs_parse_ls_lga, test_vfs_parse_ls_lga_ds)
     mctest_assert_int_eq (etalon_stat.st_mode, test_stat.st_mode);
     mctest_assert_int_eq (etalon_stat.st_uid, test_stat.st_uid);
     mctest_assert_int_eq (etalon_stat.st_gid, test_stat.st_gid);
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
     mctest_assert_int_eq (etalon_stat.st_rdev, test_stat.st_rdev);
+#endif
     mctest_assert_int_eq (etalon_stat.st_size, test_stat.st_size);
+#ifdef HAVE_STRUCT_STAT_ST_BLKSIZE
     mctest_assert_int_eq (etalon_stat.st_blksize, test_stat.st_blksize);
+#endif
+#ifdef HAVE_STRUCT_STAT_ST_BLOCKS
     mctest_assert_int_eq (etalon_stat.st_blocks, test_stat.st_blocks);
+#endif
 
     /* FIXME: these commented checks are related to time zone!
        mctest_assert_int_eq (etalon_stat.st_atime, test_stat.st_atime);
